summaryrefslogtreecommitdiff
path: root/src/gallium
diff options
context:
space:
mode:
authorVinson Lee <vlee@freedesktop.org>2021-01-02 17:11:56 -0800
committerVinson Lee <vlee@freedesktop.org>2021-01-07 20:42:36 -0800
commite248119a82e8e13d8c071589433baf91c87eb064 (patch)
tree584f02bcad9521248bfed610e6a03ceda1ddbdf2 /src/gallium
parentf1b51d472a7b8231b5627fdcaa00740e0ffb64fc (diff)
r300: Fix typos.
Signed-off-by: Vinson Lee <vlee@freedesktop.org> Reviewed-by: Marek Olšák <marek.olsak@amd.com> Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/8296>
Diffstat (limited to 'src/gallium')
-rw-r--r--src/gallium/drivers/r300/compiler/r300_fragprog_swizzle.c2
-rw-r--r--src/gallium/drivers/r300/compiler/r500_fragprog_emit.c2
-rw-r--r--src/gallium/drivers/r300/compiler/radeon_dataflow.c2
-rw-r--r--src/gallium/drivers/r300/compiler/radeon_emulate_loops.c4
-rw-r--r--src/gallium/drivers/r300/compiler/radeon_inline_literals.c4
-rw-r--r--src/gallium/drivers/r300/compiler/radeon_optimize.c2
-rw-r--r--src/gallium/drivers/r300/compiler/radeon_pair_schedule.c8
-rw-r--r--src/gallium/drivers/r300/compiler/radeon_variable.c2
-rw-r--r--src/gallium/drivers/r300/r300_reg.h8
-rw-r--r--src/gallium/drivers/r300/r300_screen.c2
-rw-r--r--src/gallium/drivers/r300/r300_state.c6
-rw-r--r--src/gallium/drivers/r300/r300_texture_desc.c2
12 files changed, 22 insertions, 22 deletions
diff --git a/src/gallium/drivers/r300/compiler/r300_fragprog_swizzle.c b/src/gallium/drivers/r300/compiler/r300_fragprog_swizzle.c
index 3ec5a42c72e..89cb9b6d9b5 100644
--- a/src/gallium/drivers/r300/compiler/r300_fragprog_swizzle.c
+++ b/src/gallium/drivers/r300/compiler/r300_fragprog_swizzle.c
@@ -91,7 +91,7 @@ static const struct swizzle_data* lookup_native_swizzle(unsigned int swizzle)
/**
* Determines if the given swizzle is valid for r300/r400. In most situations
- * it is better to use r300_swizzle_is_native() which can be accesed via
+ * it is better to use r300_swizzle_is_native() which can be accessed via
* struct radeon_compiler *c; c->SwizzleCaps->IsNative().
*/
int r300_swizzle_is_native_basic(unsigned int swizzle)
diff --git a/src/gallium/drivers/r300/compiler/r500_fragprog_emit.c b/src/gallium/drivers/r300/compiler/r500_fragprog_emit.c
index a50b86798b6..46e7e6e469f 100644
--- a/src/gallium/drivers/r300/compiler/r500_fragprog_emit.c
+++ b/src/gallium/drivers/r300/compiler/r500_fragprog_emit.c
@@ -451,7 +451,7 @@ static void emit_flowcontrol(struct emit_state * s, struct rc_instruction * inst
newip = ++s->Code->inst_end;
- /* Currently all loops use the same integer constant to intialize
+ /* Currently all loops use the same integer constant to initialize
* the loop variables. */
if(!s->Code->int_constants[0]) {
s->Code->int_constants[0] = R500_FC_INT_CONST_KR(0xff);
diff --git a/src/gallium/drivers/r300/compiler/radeon_dataflow.c b/src/gallium/drivers/r300/compiler/radeon_dataflow.c
index 03127eb63bd..302576b9fed 100644
--- a/src/gallium/drivers/r300/compiler/radeon_dataflow.c
+++ b/src/gallium/drivers/r300/compiler/radeon_dataflow.c
@@ -610,7 +610,7 @@ static void get_readers_normal_read_callback(
/**
* This function is used by rc_get_readers_normal() to determine when
- * userdata->ReaderData->Writer is dead (i. e. All compontents of its
+ * userdata->ReaderData->Writer is dead (i. e. All components of its
* destination register have been overwritten by other instructions).
*/
static void get_readers_write_callback(
diff --git a/src/gallium/drivers/r300/compiler/radeon_emulate_loops.c b/src/gallium/drivers/r300/compiler/radeon_emulate_loops.c
index d42b3e793d2..a7f773c265c 100644
--- a/src/gallium/drivers/r300/compiler/radeon_emulate_loops.c
+++ b/src/gallium/drivers/r300/compiler/radeon_emulate_loops.c
@@ -341,7 +341,7 @@ static int build_loop_info(struct radeon_compiler * c, struct loop_info * loop,
for(ptr = loop->BeginLoop->Next; !loop->EndLoop; ptr = ptr->Next) {
if (ptr == &c->Program.Instructions) {
- rc_error(c, "%s: BGNLOOP without an ENDLOOOP.\n",
+ rc_error(c, "%s: BGNLOOP without an ENDLOOP.\n",
__FUNCTION__);
return 0;
}
@@ -362,7 +362,7 @@ static int build_loop_info(struct radeon_compiler * c, struct loop_info * loop,
}
}
if (ptr == &c->Program.Instructions) {
- rc_error(c, "%s: BGNLOOP without an ENDLOOOP\n",
+ rc_error(c, "%s: BGNLOOP without an ENDLOOP\n",
__FUNCTION__);
return 0;
}
diff --git a/src/gallium/drivers/r300/compiler/radeon_inline_literals.c b/src/gallium/drivers/r300/compiler/radeon_inline_literals.c
index c40a3807de4..c419f7c3d11 100644
--- a/src/gallium/drivers/r300/compiler/radeon_inline_literals.c
+++ b/src/gallium/drivers/r300/compiler/radeon_inline_literals.c
@@ -64,8 +64,8 @@ static int ieee_754_to_r300_float(float f, unsigned char *r300_float_out)
}
if (mantissa & mantissa_mask) {
- DBG("Failed mantisa has too many bits:\n"
- "manitssa=0x%x mantissa_mask=0x%x, and=0x%x\n\n",
+ DBG("Failed mantissa has too many bits:\n"
+ "mantissa=0x%x mantissa_mask=0x%x, and=0x%x\n\n",
mantissa, mantissa_mask,
mantissa & mantissa_mask);
return 0;
diff --git a/src/gallium/drivers/r300/compiler/radeon_optimize.c b/src/gallium/drivers/r300/compiler/radeon_optimize.c
index 3bbfe898cc2..5e3503b2129 100644
--- a/src/gallium/drivers/r300/compiler/radeon_optimize.c
+++ b/src/gallium/drivers/r300/compiler/radeon_optimize.c
@@ -421,7 +421,7 @@ static void constant_folding(struct radeon_compiler * c, struct rc_instruction *
/**
* If src and dst use the same register, this function returns a writemask that
- * indicates wich components are read by src. Otherwise zero is returned.
+ * indicates which components are read by src. Otherwise zero is returned.
*/
static unsigned int src_reads_dst_mask(struct rc_src_register src,
struct rc_dst_register dst)
diff --git a/src/gallium/drivers/r300/compiler/radeon_variable.c b/src/gallium/drivers/r300/compiler/radeon_variable.c
index 7730b937372..6aec0940d80 100644
--- a/src/gallium/drivers/r300/compiler/radeon_variable.c
+++ b/src/gallium/drivers/r300/compiler/radeon_variable.c
@@ -490,7 +490,7 @@ struct rc_list * rc_variable_list_get_writers(
rc_list(&var->C->Pool, friend));
}
}
- /* Once we have indentifed the variable and its
+ /* Once we have identified the variable and its
* friends that write this source, we can stop
* stop searching, because we know none of the
* other variables in the list will write this source.
diff --git a/src/gallium/drivers/r300/r300_reg.h b/src/gallium/drivers/r300/r300_reg.h
index 9c93b84ee5f..05d85cf4749 100644
--- a/src/gallium/drivers/r300/r300_reg.h
+++ b/src/gallium/drivers/r300/r300_reg.h
@@ -323,7 +323,7 @@ USE OR OTHER DEALINGS IN THE SOFTWARE.
*
* In immediate mode, the pattern is always set to xyzw. In vertex array
* mode, the swizzling pattern is e.g. used to set zw components in texture
- * coordinates with only tweo components.
+ * coordinates with only two components.
*/
#define R300_VAP_PROG_STREAM_CNTL_EXT_0 0x21e0
# define R300_SWIZZLE0_SHIFT 0
@@ -856,7 +856,7 @@ USE OR OTHER DEALINGS IN THE SOFTWARE.
# define R500_TX_WEIGHT_PAIR (1<<22)
# define R500_TX_PHASE_SHIFT (23)
# define R500_TX_DIRECTION_HORIZONTAL (0<<27)
-# define R500_TX_DIRECTION_VERITCAL (1<<27)
+# define R500_TX_DIRECTION_VERTICAL (1<<27)
#define R500_SU_TEX_WRAP_PS3 0x4114
@@ -1148,7 +1148,7 @@ USE OR OTHER DEALINGS IN THE SOFTWARE.
# define R300_GA_POLY_MODE_BACK_PTYPE_TRI (2 << 7)
/* reserved */
-/* Specifies the rouding mode for geometry & color SPFP to FP conversions. */
+/* Specifies the rounding mode for geometry & color SPFP to FP conversions. */
#define R300_GA_ROUND_MODE 0x428c
# define R300_GA_ROUND_MODE_GEOMETRY_ROUND_TRUNC (0 << 0)
# define R300_GA_ROUND_MODE_GEOMETRY_ROUND_NEAREST (1 << 0)
@@ -1842,7 +1842,7 @@ USE OR OTHER DEALINGS IN THE SOFTWARE.
# define R400_SRC_ADDR_EXT_BIT (1 << 19)
# define R400_DST_ADDR_EXT_BIT (1 << 20)
-/* Output format from the unfied shader */
+/* Output format from the unified shader */
#define R300_US_OUT_FMT_0 0x46A4
# define R300_US_OUT_FMT_C4_8 (0 << 0)
# define R300_US_OUT_FMT_C4_10 (1 << 0)
diff --git a/src/gallium/drivers/r300/r300_screen.c b/src/gallium/drivers/r300/r300_screen.c
index c841e68c6e5..c1579d9df9d 100644
--- a/src/gallium/drivers/r300/r300_screen.c
+++ b/src/gallium/drivers/r300/r300_screen.c
@@ -161,7 +161,7 @@ static int r300_get_param(struct pipe_screen* pscreen, enum pipe_cap param)
return r300screen->caps.dxtc_swizzle;
/* We don't support color clamping on r500, so that we can use color
- * intepolators for generic varyings. */
+ * interpolators for generic varyings. */
case PIPE_CAP_VERTEX_COLOR_CLAMPED:
return !is_r500;
diff --git a/src/gallium/drivers/r300/r300_state.c b/src/gallium/drivers/r300/r300_state.c
index f5cbc93686d..0e5d0392bfd 100644
--- a/src/gallium/drivers/r300/r300_state.c
+++ b/src/gallium/drivers/r300/r300_state.c
@@ -47,7 +47,7 @@
#include "r300_texture.h"
#include "r300_vs.h"
-/* r300_state: Functions used to intialize state context by translating
+/* r300_state: Functions used to initialize state context by translating
* Gallium state objects into semi-native r300 state objects. */
#define UPDATE_STATE(cso, atom) \
@@ -1502,7 +1502,7 @@ static uint32_t r300_assign_texture_cache_region(unsigned index, unsigned num)
* EIGHTH_0 = 8
* EIGHTH_1 = 9
*
- * First 3 textures will get 3/4 of size of the cache, divived evenly
+ * First 3 textures will get 3/4 of size of the cache, divided evenly
* between them. The last 1/4 of the cache must be divided between
* the last 2 textures, each will therefore get 1/8 of the cache.
* Why not just to use "5 + texture_index" ?
@@ -1618,7 +1618,7 @@ r300_create_sampler_view_custom(struct pipe_context *pipe,
dxtc_swizzle);
if (hwformat == ~0) {
- fprintf(stderr, "r300: Ooops. Got unsupported format %s in %s.\n",
+ fprintf(stderr, "r300: Oops. Got unsupported format %s in %s.\n",
util_format_short_name(templ->format), __func__);
}
assert(hwformat != ~0);
diff --git a/src/gallium/drivers/r300/r300_texture_desc.c b/src/gallium/drivers/r300/r300_texture_desc.c
index 5da35fba7e1..face4a7d965 100644
--- a/src/gallium/drivers/r300/r300_texture_desc.c
+++ b/src/gallium/drivers/r300/r300_texture_desc.c
@@ -618,7 +618,7 @@ void r300_texture_desc_init(struct r300_screen *rscreen,
"This can be a DDX bug. Got: %"PRIu64"B, Need: %uB, Info:\n",
tex->buf->size, tex->tex.size_in_bytes);
r300_tex_print_info(tex, "texture_desc_init");
- /* Ooops, what now. Apps will break if we fail this,
+ /* Oops, what now. Apps will break if we fail this,
* so just pretend everything's okay. */
}
}
diff --git a/src/gallium/drivers/r300/compiler/radeon_pair_schedule.c b/src/gallium/drivers/r300/compiler/radeon_pair_schedule.c
index df54b084de1..f652d0f618e 100644
--- a/src/gallium/drivers/r300/compiler/radeon_pair_schedule.c
+++ b/src/gallium/drivers/r300/compiler/radeon_pair_schedule.c
@@ -65,7 +65,7 @@ struct schedule_instruction {
struct rc_reader_data GlobalReaders;
/** If the scheduler has paired an RGB and an Alpha instruction together,
* PairedInst references the alpha insturction's dependency information.
*/
struct schedule_instruction * PairedInst;
@@ -107,7 +107,7 @@ struct reg_value {
/**
* Number of readers of this value. This is decremented each time
* a reader of the value is committed.
- * When the reader cound reaches zero, the dependency count
+ * When the reader count reaches zero, the dependency count
* of the instruction writing \ref Next is decremented.
*/
unsigned int NumReaders;
@@ -120,7 +120,7 @@ struct register_state {
};
struct remap_reg {
- struct rc_instruciont * Inst;
+ struct rc_instruction * Inst;
unsigned int OldIndex:(RC_REGISTER_INDEX_BITS+1);
unsigned int OldSwizzle:3;
unsigned int NewIndex:(RC_REGISTER_INDEX_BITS+1);
@@ -865,7 +865,7 @@ static void is_rgb_to_alpha_possible(
/* Make sure there are enough alpha sources.
* XXX If we know what register all the readers are going
* to be remapped to, then in some situations we can still do
- * the subsitution, even if all 3 alpha sources are being used.*/
+ * the substitution, even if all 3 alpha sources are being used.*/
for (i = 0; i < 3; i++) {
if (inst->U.P.Alpha.Src[i].Used) {
alpha_sources++;
@@ -65,7 +65,7 @@ struct schedule_instruction {
struct rc_reader_data GlobalReaders;
/** If the scheduler has paired an RGB and an Alpha instruction together,
- * PairedInst references the alpha insturction's dependency information.
+ * PairedInst references the alpha instruction's dependency information.
*/
struct schedule_instruction * PairedInst;